@@ -1,3 +1,4 @@
+#include "config.h"
 #include "mold.h"
 
 #include <filesystem>
@@ -706,13 +707,13 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
     } else if (read_flag("no-dynamic-linker")) {
       ctx.arg.dynamic_linker = "";
     } else if (read_flag("v")) {
-      Out(ctx) << get_mold_version();
+      Out(ctx) << mold_version;
       version_shown = true;
     } else if (read_flag("version")) {
-      Out(ctx) << get_mold_version();
+      Out(ctx) << mold_version;
       exit(0);
     } else if (read_flag("V")) {
-      Out(ctx) << get_mold_version()
+      Out(ctx) << mold_version
                << "\n  Supported emulations:\n   elf_x86_64\n   elf_i386\n"
                << "   aarch64elf\n   aarch64linux\n   aarch64elfb\n"
                << "   aarch64linuxb\n   armelf_linux_eabi\n   elf64lriscv\n"
@@ -858,10 +859,8 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
     } else if (read_arg("sysroot")) {
       ctx.arg.sysroot = arg;
     } else if (read_arg("unique")) {
-      std::optional<Glob> pat = Glob::compile(arg);
-      if (!pat)
+      if (!ctx.arg.unique.add(arg, 1))
         Fatal(ctx) << "-unique: invalid glob pattern: " << arg;
-      ctx.arg.unique = std::move(*pat);
     } else if (read_arg("unresolved-symbols")) {
       if (arg == "report-all" || arg == "ignore-in-shared-libs")
         report_undefined = true;
@@ -981,11 +980,11 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
       ctx.arg.execute_only = true;
     } else if (read_arg("compress-debug-sections")) {
       if (arg == "zlib" || arg == "zlib-gabi")
-        ctx.arg.compress_debug_sections = COMPRESS_ZLIB;
+        ctx.arg.compress_debug_sections = ELFCOMPRESS_ZLIB;
       else if (arg == "zstd")
-        ctx.arg.compress_debug_sections = COMPRESS_ZSTD;
+        ctx.arg.compress_debug_sections = ELFCOMPRESS_ZSTD;
       else if (arg == "none")
-        ctx.arg.compress_debug_sections = COMPRESS_NONE;
+        ctx.arg.compress_debug_sections = ELFCOMPRESS_NONE;
       else
         Fatal(ctx) << "invalid --compress-debug-sections argument: " << arg;
     } else if (read_arg("wrap")) {
@@ -1444,6 +1443,9 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
   if (ctx.arg.relocatable)
     ctx.arg.static_ = true;
 
+  if (ctx.arg.static_)
+    ctx.arg.dynamic_linker = "";
+
   if (ctx.arg.shuffle_sections == SHUFFLE_SECTIONS_SHUFFLE) {
     if (shuffle_sections_seed)
       ctx.arg.shuffle_sections_seed = *shuffle_sections_seed;
