@@ -6,7 +6,7 @@ void foo() {}
 EOF
 
 # The compiler might not create .riscv.attributes
-readelf --sections $t/a.o | grep -Fq .riscv.attributes || skip
+readelf --sections $t/a.o | grep -F .riscv.attributes || skip
 
 cat <<EOF | $CC -march=rv64imafd_xtheadba2p0 -o $t/b.o -c -xc -
 void bar() {}
@@ -17,7 +17,7 @@ void _start() {}
 EOF
 
 $CC -B. -nostdlib -o $t/exe $t/a.o $t/c.o
-readelf -A $t/exe | grep -q '_xtheadba1p5"'
+readelf -A $t/exe | grep '_xtheadba1p5"'
 
 $CC -B. -nostdlib -o $t/exe $t/a.o $t/b.o $t/c.o
-readelf -A $t/exe | grep -q '_xtheadba2p0"'
+readelf -A $t/exe | grep '_xtheadba2p0"'
